# SPDX-License-Identifier: MIT

import logging

from robosignatory.utils import BaseSigningHelper


log = logging.getLogger("calligrabot.signer")


class RPMSigningHelper(BaseSigningHelper):
    def __init__(
        self,
        user,
        principal,
        keytab,
        ima_key=None,
        config_file=None,
        dry_run=None,
    ):
        self.user = user
        self.principal = principal
        self.keytab = keytab
        self.ima_key = ima_key
        self.config_file = config_file
        self.dry_run = dry_run

    def build_cmdline(self, *args):
        cmdline = [
            "calligrabot",
            "--user-name",
            self.user,
        ]
        if self.principal:
            cmdline.extend(["--principal", self.principal])
        if self.keytab:
            cmdline.extend(["--keytab", self.keytab])
        if self.config_file:
            cmdline.extend(["--config-file", self.config_file])
        if self.dry_run:
            cmdline.extend(["--dry-run"])
        cmdline.extend(args)
        return cmdline

    def build_sign_cmdline(
        self, key, rpms, koji_instance, file_signing_key=None
    ):
        # Note: robosignatory supplies file_signing_key as a positional
        # argument, but it's not needed here

        command = self.build_cmdline("sign-rpms")

        if self.ima_key:
            command.extend(["--ima-sign-key", self.ima_key])
        if koji_instance:
            command.extend(["--koji-instance", koji_instance])

        if file_signing_key:
            log.debug("Ignoring unneeded signing key: %s", file_signing_key)

        command.append(key)

        return command + rpms

    def build_atomic_cmdline(self, *args, **kwargs):
        result = [
            "echo",
            " ".join(["build_atomic_cmdline:", str(args), str(kwargs)]),
        ]
        log.info(result)
        return result

    def build_coreos_cmdline(self, *args, **kwargs):
        result = [
            "echo",
            " ".join(["build_coreos_cmdline:", str(args), str(kwargs)]),
        ]
        log.info(result)
        return result
